services package reference
============================

auth module
-----------------------
.. automodule:: letterboxd.services.auth
   :members:

film module
----------------
.. automodule:: letterboxd.services.film
   :members:

member module
-----------------
.. automodule:: letterboxd.services.member
   :members: